@@ -1,5 +1,5 @@
 #############################################################################
-#  $Id: Genders.pm.in,v 1.3 2005/05/07 18:23:13 achu Exp $
+#  $Id: Genders.pm.in,v 1.7 2007/01/10 18:52:54 achu Exp $
 #############################################################################
 #  Copyright (C) 2001-2003 The Regents of the University of California.
 #  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -421,10 +421,16 @@ indexes.
 
 =item B<$obj-E<gt>query($query)>
 
-Query the genders database based on the union, intersection, or set
-difference between genders attributes and values.  Use plus ('|') for
-union, comma ('&') for intersection and minus ('-') for set
-difference.
+Returns a list of nodes specified by a genders query.  A genders query
+is based on the union, intersection, set difference, or complement
+between genders attributes and values.  Union is represented by two
+pipe symbols ('||'), intersection by two ampersand symbols ('&&'),
+difference by two minus symbols ('--'), and complement by a tilde
+('~') Operations are performed from left to right.  Parentheses may be
+used to change the order of operations.  For example, the following
+query would retrieve all nodes other than management or login nodes:
+"all-(mgmt+login)".  If the query is not specified, all nodes listed
+in the genders file are returned.
 
 =back 
 
