@@ -1,5 +1,5 @@
 #############################################################################
-#  $Id: Libgenders.pm.in,v 1.1 2005/01/10 16:45:35 achu Exp $
+#  $Id: Libgenders.pm.in,v 1.5 2007/01/10 18:52:54 achu Exp $
 #############################################################################
 #  Copyright (C) 2001-2003 The Regents of the University of California.
 #  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -244,13 +244,17 @@ with a different attribute will overwrite earlier indexes.
 
 =item B<$handle-E<gt>genders_query($query)>
 
-Query the genders database based on the union, intersection, or set
-difference between genders attributes and values.  Use plus ('|') for
-union, comma ('&') for intersection and minus ('-') for set
-difference.  Operations are performed from left to right.  Parentheses
-may be used to change the order of operations.  For example, the
-following query would retrieve all nodes other than management or
-login nodes: "all-(mgmt+login)".
+Returns a reference to a list of nodes specified by a genders query.
+A genders query is based on the union, intersection, set difference,
+or complement between genders attributes and values.  Union is
+represented by two pipe symbols ('||'), intersection by two ampersand
+symbols ('&&'), difference by two minus symbols ('--'), and complement
+by a tilde ('~') Operations are performed from left to right.
+Parentheses may be used to change the order of operations.  For
+example, the following query would retrieve all nodes other than
+management or login nodes: "all-(mgmt+login)".  If $query is not
+specified, all nodes listed in the genders file are returned. Returns
+undef on error.
 
 =item B<$handle-E<gt>genders_parse([$filename])>
 
