@@ -77,7 +77,7 @@
 #line 1 "./genders_query.y"
 
 /*****************************************************************************\
- *  $Id: genders_query.y,v 1.26 2005/05/07 17:24:31 achu Exp $
+ *  $Id: genders_query.y,v 1.27 2007/01/10 18:52:54 achu Exp $
  *****************************************************************************
  *  Copyright (C) 2001-2003 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -114,7 +114,9 @@
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
+#if HAVE_PATHS_H
 #include <paths.h>
+#endif /* HAVE_PATHS_H */
 
 #include "genders.h"
 #include "genders_api.h"
@@ -147,6 +149,10 @@ static int genders_query_err = 0;
  */ 
 static struct genders_treenode *genders_treeroot = NULL;
 
+#ifndef _PATH_DEVNULL
+#define _PATH_DEVNULL "/dev/null"
+#endif /* _PATH_DEVNULL */
+
 extern int yylex();
 extern int yyparse(void);
 
@@ -674,13 +680,13 @@ genders_query(genders_t handle, char *nodes[], int len, char *query)
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 589 "./genders_query.y"
+#line 595 "./genders_query.y"
 typedef union YYSTYPE {
   char *attr;
   struct genders_treenode *tree;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 684 "genders_query.c"
+#line 690 "genders_query.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -692,7 +698,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 696 "genders_query.c"
+#line 702 "genders_query.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -867,7 +873,7 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short yyrline[] =
 {
-       0,   597,   597,   603,   604,   608,   612,   618,   622,   626
+       0,   603,   603,   609,   610,   614,   618,   624,   628,   632
 };
 #endif
 
@@ -1566,54 +1572,54 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 598 "./genders_query.y"
+#line 604 "./genders_query.y"
     {
              genders_treeroot = yyvsp[0].tree;
            }
     break;
 
   case 3:
-#line 603 "./genders_query.y"
+#line 609 "./genders_query.y"
     {yyval.tree = yyvsp[0].tree;}
     break;
 
   case 4:
-#line 605 "./genders_query.y"
+#line 611 "./genders_query.y"
     {
              yyval.tree = _genders_makenode("||", yyvsp[-2].tree, yyvsp[0].tree);
            }
     break;
 
   case 5:
-#line 609 "./genders_query.y"
+#line 615 "./genders_query.y"
     {
              yyval.tree = _genders_makenode("&&", yyvsp[-2].tree, yyvsp[0].tree);
            }
     break;
 
   case 6:
-#line 613 "./genders_query.y"
+#line 619 "./genders_query.y"
     {
              yyval.tree = _genders_makenode("--", yyvsp[-2].tree, yyvsp[0].tree);
            }
     break;
 
   case 7:
-#line 619 "./genders_query.y"
+#line 625 "./genders_query.y"
     {
              yyval.tree = _genders_makenode(yyvsp[0].attr, NULL, NULL);
            }
     break;
 
   case 8:
-#line 623 "./genders_query.y"
+#line 629 "./genders_query.y"
     {
              yyval.tree = yyvsp[-1].tree;
            }
     break;
 
   case 9:
-#line 627 "./genders_query.y"
+#line 633 "./genders_query.y"
     {
              _genders_set_complement_flag(yyvsp[0].tree);
              yyval.tree = yyvsp[0].tree;
@@ -1624,7 +1630,7 @@ yyreduce:
     }
 
 /* Line 1000 of yacc.c.  */
-#line 1628 "genders_query.c"
+#line 1634 "genders_query.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1849,6 +1855,6 @@ yyreturn:
 }
 
 
-#line 631 "./genders_query.y"
+#line 637 "./genders_query.y"
 
 
