@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: genders_test_corner_case.c,v 1.3 2005/01/03 17:31:21 achu Exp $
+ *  $Id: genders_test_corner_case.c,v 1.9 2007/01/10 18:52:54 achu Exp $
  *****************************************************************************
  *  Copyright (C) 2001-2003 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -26,7 +26,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <paths.h>		/* _PATH_DEVNULL */
 #include <unistd.h>		/* gethostname */
 #include <sys/param.h>		/* MAXHOSTNAMELEN */
 #include <string.h>
@@ -34,12 +33,24 @@
 #include <sys/stat.h>       	/* stat() */
 #include <errno.h>
 #include <assert.h>
+#include <fcntl.h>       	/* O_APPEND */
+#if HAVE_PATHS_H
+#include <paths.h>		/* _PATH_DEVNULL */
+#endif /* HAVE_PATHS_H */
 
 #include "genders.h"
 #include "genders_testlib.h"
 #include "genders_test_corner_case.h"
 #include "genders_test_database.h"
 
+#ifndef _PATH_DEVNULL
+#define _PATH_DEVNULL "/dev/null"
+#endif /* _PATH_DEVNULL */
+
+#ifndef MAXHOSTNAMELEN
+#define MAXHOSTNAMELEN    64
+#endif /* MAXHOSTNAMELEN */
+
 static genders_t 
 genders_unloaded_handle(void) 
 {
@@ -334,13 +345,14 @@ genders_perror_corner_case(int verbose)
 {
   int i = 0;
   int errcount = 0;
-  FILE *stderr_save;
-  FILE *dev_null;
+  int stderr_save;
+  int dev_null;
   genders_perror_corner_case_t *tests = &genders_perror_corner_case_tests[0];
 
-  stderr_save = stderr;
-  if (!(dev_null = fopen(_PATH_DEVNULL, "r+")))
-    genders_err_exit("fopen: %s: %s", _PATH_DEVNULL, strerror(errno));
+  if ((stderr_save = dup(STDERR_FILENO)) < 0)
+    genders_err_exit("dup: %s", strerror(errno));
+  if ((dev_null = open(_PATH_DEVNULL, O_APPEND)) < 0)
+    genders_err_exit("open: %s: %s", _PATH_DEVNULL, strerror(errno));
   
   while (!(tests[i].num < 0)) 
     {
@@ -349,9 +361,11 @@ genders_perror_corner_case(int verbose)
 
       /* Must route stderr somewhere else during call to genders_perror() */
       handle = genders_handle_get(tests[i].param1);
-      stderr = dev_null;
+      if ((dup2(dev_null, STDERR_FILENO)) < 0)
+	genders_err_exit("dup2: %s", strerror(errno));
       genders_perror(handle, tests[i].param2);
-      stderr = stderr_save;
+      if ((dup2(stderr_save, STDERR_FILENO)) < 0)
+	genders_err_exit("dup2: %s", strerror(errno));
       errnum = genders_errnum(handle);
 
       err = genders_errnum_check("genders_errnum",
@@ -366,7 +380,7 @@ genders_perror_corner_case(int verbose)
       i++;
     }
 
-  fclose(dev_null);
+  close(dev_null);
   return errcount;
 }
 
@@ -611,7 +625,8 @@ _genders_list_clear_corner_case(GendersListCreateFunc funccreate,
 				int expected_errnum,
 				int verbose)
 {
-  genders_t gh, handle;
+  genders_t gh = NULL;
+  genders_t handle;
   char **list;
   int return_value, errnum, err;
 
@@ -666,7 +681,8 @@ _genders_list_destroy_corner_case(GendersListCreateFunc funccreate,
 				  int expected_errnum,
 				  int verbose)
 {
-  genders_t gh, handle;
+  genders_t gh = NULL;
+  genders_t handle;
   char **list;
   int return_value, errnum, err;
 
@@ -1399,8 +1415,8 @@ genders_parse_corner_case(int verbose)
   int i = 0;
   int errcount = 0;
   genders_parse_corner_case_t *tests = &genders_parse_corner_case_tests[0];
-  FILE *stderr_save;
-  FILE *dev_null;
+  int stderr_save;
+  int dev_null;
 
   /* Special case for tests 6,7,18,19.  It depends on if the default
    * genders file exists on the system and the tester has access to
@@ -1422,9 +1438,10 @@ genders_parse_corner_case(int verbose)
       }
   }
 
-  stderr_save = stderr;
-  if (!(dev_null = fopen(_PATH_DEVNULL, "r+")))
-    genders_err_exit("fopen: %s: %s", _PATH_DEVNULL, strerror(errno));
+  if ((stderr_save = dup(STDERR_FILENO)) < 0)
+    genders_err_exit("dup: %s", strerror(errno));
+  if ((dev_null = open(_PATH_DEVNULL, O_APPEND)) < 0)
+    genders_err_exit("open: %s: %s", _PATH_DEVNULL, strerror(errno));
 
   while (!(tests[i].num < 0)) 
     {
@@ -1437,9 +1454,11 @@ genders_parse_corner_case(int verbose)
       filename = genders_filename_get(tests[i].param2);
       streamptr = (tests[i].param3 == GENDERS_POINTER_NULL) ? NULL : stderr;
       /* Must route stderr somewhere else during call to genders_parse() */
-      stderr = dev_null;
+      if ((dup2(dev_null, STDERR_FILENO)) < 0)
+	genders_err_exit("dup2: %s", strerror(errno));
       return_value = genders_parse(handle, filename, streamptr);
-      stderr = stderr_save;
+      if ((dup2(stderr_save, STDERR_FILENO)) < 0)
+	genders_err_exit("dup2: %s", strerror(errno));
       errnum = genders_errnum(handle);
 
       errcount += genders_return_value_errnum_check("genders_parse",
@@ -1455,7 +1474,7 @@ genders_parse_corner_case(int verbose)
       i++;
     }
 
-  fclose(dev_null);
+  close(dev_null);
   return errcount;
 }
 
