@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: genders_test_query_tests.c,v 1.1 2005/01/03 17:31:21 achu Exp $
+ *  $Id: genders_test_query_tests.c,v 1.2 2007/01/10 18:52:54 achu Exp $
  *****************************************************************************
  *  Copyright (C) 2001-2003 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -2476,6 +2476,21 @@ genders_query_tests_t genders_query_functionality_tests_query_special_chars_test
 	{"node1", NULL},
 	1,
       },
+      {
+	"attr:colon",
+	{"node1", NULL},
+	1,
+      },
+      {
+	"attr\\backslash",
+	{"node1", NULL},
+	1,
+      },
+      {
+	"attr/forwardslash",
+	{"node1", NULL},
+	1,
+      },
       {
 	"attr%foo%percent",
 	{"node2", NULL},
@@ -2496,6 +2511,56 @@ genders_query_tests_t genders_query_functionality_tests_query_special_chars_test
 	{"node2", NULL},
 	1,
       },
+      {
+	"attr:foo:colon",
+	{"node2", NULL},
+	1,
+      },
+      {
+	"attr\\foo\\backslash",
+	{"node2", NULL},
+	1,
+      },
+      {
+	"attr/foo/forwardslash",
+	{"node2", NULL},
+	1,
+      },
+      {
+	"attr1=attr1%percent",
+	{"node3", NULL},
+	1,
+      },
+      {
+	"attr2=attr2|pipe",
+	{"node3", NULL},
+	1,
+      },
+      {
+	"attr3=attr3&ampersand",
+	{"node3", NULL},
+	1,
+      },
+      {
+	"attr4=attr4-minus",
+	{"node3", NULL},
+	1,
+      },
+      {
+	"attr5=attr5:colon",
+	{"node3", NULL},
+	1,
+      },
+      {
+	"attr6=attr6\\backslash",
+	{"node3", NULL},
+	1,
+      },
+      {
+	"attr7=attr7/forwardslash",
+	{"node3", NULL},
+	1,
+      },
       {
 	NULL,
 	{NULL},
